==> contentsquare-1.3.2.tar.gz: test/src/modules/logger/logger_test.dart <==
import 'package:contentsquare/src/modules/logger/logger.dart';
import 'package:flutter_test/flutter_test.dart';

import '../../../helpers/expect_logs.dart';
import '../../../helpers/matchers/fixtures/matcher.dart';

class CustomLog extends ContentsquareLog {
  @override
  String get message => 'CustomLog message';
}

void main() {
  group('isMultiLines', () {
    test('should return false is the string is a single line', () {
      const singleLineString = 'This is a single line string';
      expect(isMultiLines(singleLineString), false);
    });

    test('should return true is the string is a multi line string', () {
      const multiLineString = 'This is a \n multi-line \n string';

      expect(isMultiLines(multiLineString), true);
    });
  });

  group('ContentsquareLog', () {
    test(
      'should return a string which matches the fixture when using [InfoLog]',
      () {
        final infoLog = InfoLog('This is an info log');
        expect(
          infoLog.toString(),
          matchesFixture('infoLog', isVersionSpecific: false),
        );
      },
    );

    test(
      'should return a string which matches the fixture when using [SuccessLog]',
      () {
        final successLog = SuccessLog('This is a success log');
        expect(
          successLog.toString(),
          matchesFixture('successLog', isVersionSpecific: false),
        );
      },
    );

    test(
      'should return a string which matches the fixture when using [WarningLog]',
      () {
        final warningLog = WarningLog('This is a warning log');
        expect(
          warningLog.toString(),
          matchesFixture('warningLog', isVersionSpecific: false),
        );
      },
    );

    test(
      'should return a string which matches the fixture when using [ErrorLog]',
      () {
        final errorLog = ErrorLog('This is an error log');
        expect(
          errorLog.toString(),
          matchesFixture('errorLog', isVersionSpecific: false),
        );
      },
    );
  });

  group('ContentsquareLogger', () {
    group('listen', () {
      test(
        'should trigger the callback given to [ContentsquareLogger.listen] with the correct log when a log is added',
        () async {
          final warningLog = WarningLog('This is a warning log');

          expectLogs((log) {
            expect(log, warningLog);
          });

          logger.add(warningLog);
        },
      );
    });

    test(
      'should emit an info log when [ContentsquareLogger.info] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<InfoLog>());
          expect(
            log.toString(),
            InfoLog('This is an info log').toString(),
          );
        });

        logger.info('This is an info log');
      },
    );

    test(
      'should emit a success log when [ContentsquareLogger.success] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<SuccessLog>());
          expect(
            log.toString(),
            SuccessLog('This is a success log').toString(),
          );
        });

        logger.success('This is a success log');
      },
    );

    test(
      'should emit a warning log when [ContentsquareLogger.warning] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<WarningLog>());
          expect(
            log.toString(),
            WarningLog('This is a warning log').toString(),
          );
        });

        logger.warning('This is a warning log');
      },
    );

    test(
      'should emit an error log when [ContentsquareLogger.error] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<ErrorLog>());
          expect(
            log.toString(),
            ErrorLog('This is an error log').toString(),
          );
        });

        logger.error('This is an error log');
      },
    );

    test(
      'should emit a custom log when [ContentsquareLogger.add] is used',
      () async {
        final customLog = CustomLog();

        expectLogs((log) => expect(log, customLog));

        logger.add(customLog);
      },
    );
  });
}

==> contentsquare-2.3.0.tar.gz: test/src/modules/logger/logger_test.dart <==
import 'package:contentsquare/src/modules/logger/logger.dart';
import 'package:flutter_test/flutter_test.dart';

import '../../../helpers/expect_logs.dart';
import '../../../helpers/matchers/fixtures/matcher.dart';

class CustomLog extends ContentsquareLog {
  @override
  String get message => 'CustomLog message';
}

void main() {
  group('isMultiLines', () {
    test('should return false is the string is a single line', () {
      const singleLineString = 'This is a single line string';
      expect(isMultiLines(singleLineString), false);
    });

    test('should return true is the string is a multi line string', () {
      const multiLineString = 'This is a \n multi-line \n string';

      expect(isMultiLines(multiLineString), true);
    });
  });

  group('ContentsquareLog', () {
    test(
      'should return a string which matches the fixture when using [InfoLog]',
      () {
        final infoLog = InfoLog('This is an info log');
        expect(
          infoLog.toString(),
          matchesFixture('infoLog', isVersionSpecific: false),
        );
      },
    );

    test(
      'should return a string which matches the fixture when using [SuccessLog]',
      () {
        final successLog = SuccessLog('This is a success log');
        expect(
          successLog.toString(),
          matchesFixture('successLog', isVersionSpecific: false),
        );
      },
    );

    test(
      'should return a string which matches the fixture when using [WarningLog]',
      () {
        final warningLog = WarningLog('This is a warning log');
        expect(
          warningLog.toString(),
          matchesFixture('warningLog', isVersionSpecific: false),
        );
      },
    );

    test(
      'should return a string which matches the fixture when using [ErrorLog]',
      () {
        final errorLog = ErrorLog('This is an error log');
        expect(
          errorLog.toString(),
          matchesFixture('errorLog', isVersionSpecific: false),
        );
      },
    );
  });

  group('ContentsquareLogger', () {
    group('listen', () {
      test(
        'should trigger the callback given to [ContentsquareLogger.listen] with the correct log '
        'when a log is added',
        () async {
          final warningLog = WarningLog('This is a warning log');

          expectLogs((log) {
            expect(log, warningLog);
          });

          logger.add(warningLog);
        },
      );
    });

    test(
      'should emit an info log when [ContentsquareLogger.info] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<InfoLog>());
          expect(
            log.toString(),
            InfoLog('This is an info log').toString(),
          );
        });

        logger.info('This is an info log');
      },
    );

    test(
      'should emit a success log when [ContentsquareLogger.success] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<SuccessLog>());
          expect(
            log.toString(),
            SuccessLog('This is a success log').toString(),
          );
        });

        logger.success('This is a success log');
      },
    );

    test(
      'should emit a warning log when [ContentsquareLogger.warning] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<WarningLog>());
          expect(
            log.toString(),
            WarningLog('This is a warning log').toString(),
          );
        });

        logger.warning('This is a warning log');
      },
    );

    test(
      'should emit an error log when [ContentsquareLogger.error] is used',
      () async {
        expectLogs((log) {
          expect(log, isA<ErrorLog>());
          expect(
            log.toString(),
            ErrorLog('This is an error log').toString(),
          );
        });

        logger.error('This is an error log');
      },
    );

    test(
      'should emit a custom log when [ContentsquareLogger.add] is used',
      () async {
        final customLog = CustomLog();

        expectLogs((log) => expect(log, customLog));

        logger.add(customLog);
      },
    );
  });
}
